//#define XERR
#include "conffile.ih"

size_t ConfFile::value(char const *id) const
{
    const_iterator iter = find(id);

    try
    {
        return iter == d_config.end() ? 0 : stoul(iter->value());
    }
    catch (...)
    {
        Error::instance()(CONFIG, iter->lineNr(), MISSING_NR) << id << "')\n";
        return 0;
    }
}
